@@ -13,8 +13,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,7 +27,6 @@
 #include <string.h>
 
 #include "support.h"
-#include "gstruct.h"
 #include "ctree.h"
 #include "tilp.h"
 #include "screenshot.h"
@@ -45,7 +44,8 @@ enum
 
 enum 
 { 
-	TARGET_STRING, TARGET_ROOTWIN, TARGET_LEFT, TARGET_RIGHT,
+	TARGET_STRING, TARGET_ROOTWIN, TARGET_TEXT_URI_LIST,
+	TARGET_LEFT, TARGET_RIGHT,
 };
 
 /*static GtkTargetEntry target_table[] = {
@@ -56,14 +56,15 @@ enum
 
 static GtkTargetEntry target_table_1[] = 
 {
-	{"clist", 0, TARGET_STRING},
-	{"application/x-rootwin-drop", 0, TARGET_ROOTWIN}
+	{(char *)"clist", 0, TARGET_STRING},
+	{(char *)"text/uri-list", 0, TARGET_TEXT_URI_LIST, },
+	{(char *)"application/x-rootwin-drop", 0, TARGET_ROOTWIN}
 };
 
 static GtkTargetEntry target_table_2[] = 
 {
-	{"ctree", 0, TARGET_STRING},
-	{"application/x-rootwin-drop", 0, TARGET_ROOTWIN}
+	{(char *)"ctree", 0, TARGET_STRING},
+	{(char *)"application/x-rootwin-drop", 0, TARGET_ROOTWIN}
 };
 
 static guint n_targets = 1;
@@ -75,7 +76,7 @@ void dnd_init(void)
 			    target_table_1, n_targets,
 			    GDK_ACTION_COPY | GDK_ACTION_MOVE);
 	gtk_drag_dest_set(ctree_wnd, GTK_DEST_DEFAULT_ALL,
-			  target_table_1, n_targets,
+			  target_table_1, n_targets+1,
 			  GDK_ACTION_COPY | GDK_ACTION_MOVE);
 
 	// from tree to list
@@ -89,25 +90,19 @@ void dnd_init(void)
 
 /* CList -> CTree */
 
-GLADE_CB void
-on_treeview2_drag_begin(GtkWidget * widget,
-			GdkDragContext * drag_context, gpointer user_data)
-{
-}
-
 // pass data
 GLADE_CB void
 on_treeview2_drag_data_get(GtkWidget * widget,
 			   GdkDragContext * drag_context,
 			   GtkSelectionData * data,
-			   guint info, guint time, gpointer user_data)
+			   guint info, guint _time, gpointer user_data)
 {
-	gchar *name = "foo_bar";
+	gchar *name = (char *)"foo_bar";
 	gtk_selection_data_set(data, data->target, 8, 
 			       (guchar *)name, strlen(name));
 }
 
-extern int on_tilp_send(gchar*);
+extern int on_tilp_send(const gchar*);
 
 // retrieve data
 GLADE_CB void
@@ -116,7 +111,7 @@ on_treeview1_drag_data_received(GtkWidget * widget,
 				gint x,
 				gint y,
 				GtkSelectionData * data,
-				guint info, guint time, gpointer user_data)
+				guint info, guint _time, gpointer user_data)
 {
 	GtkTreeView *view = GTK_TREE_VIEW(widget);
 	GtkTreeModel *model = gtk_tree_view_get_model(view);
@@ -125,17 +120,35 @@ on_treeview1_drag_data_received(GtkWidget * widget,
 	GtkTreeIter iter;
 	VarEntry *ve;
 	gchar *name;
+	gchar *target = NULL;
+	gboolean success = FALSE;
 
-	if ((data->length >= 0) && (data->format == 8)) 
+	if ((data->length >= 0) && (data->format == 8))
 	{
-		gtk_tree_view_get_dest_row_at_pos(view, x, y, &path, &pos);
-		if (path == NULL) 
+		if (drag_context->action == GDK_ACTION_ASK)
 		{
-			gtk_drag_finish(drag_context, FALSE, FALSE, time);
-			return;
+			drag_context->action = GDK_ACTION_COPY;
 		}
-		gtk_tree_model_get_iter(model, &iter, path);
 
+		if (info == TARGET_TEXT_URI_LIST)
+		{
+			int i;
+			gchar **list;
+			//list = g_uri_list_extract_uris((gchar *)gtk_selection_data_get_data(data));
+			list = gtk_selection_data_get_uris(data);
+			tilp_local_selection_destroy();
+			for (i = 0;list[i] != NULL; i++)
+			{
+				name = g_filename_from_uri(list[i], NULL, NULL);
+				tilp_local_selection_add(name);
+			}
+			g_strfreev(list);
+		}
+
+		gtk_tree_view_get_dest_row_at_pos(view, x, y, &path, &pos);
+		if (path == NULL)
+			goto end;
+		gtk_tree_model_get_iter(model, &iter, path);
 		gtk_tree_model_get(model, &iter, COLUMN_DATA, &ve, -1);
 		gtk_tree_model_get(model, &iter, COLUMN_NAME, &name, -1);
 
@@ -143,39 +156,24 @@ on_treeview1_drag_data_received(GtkWidget * widget,
 
 		if(strchr(name, '#'))			// Calc
 		{
-			//on_tilp_button8_clicked(NULL, NULL);
-			gtk_drag_finish(drag_context, TRUE, FALSE, time);
-			return;
 		}
 		else if(!strcmp(name, NODE4))	// Applications
 		{
 			// send to flash
-			on_tilp_send("<FLASH>");
-			gtk_drag_finish(drag_context, TRUE, FALSE, time);
-			return;
+			target=(char *)"<FLASH>";
 		}
-
 		else if (ve && tifiles_has_folder(options.calc_model))
 		{
 			// send to folder
-			char *target;
-
 			if(!strcmp(ve->folder, ""))
 				target = ve->name;
 			else
 				target = ve->folder;
-			on_tilp_send(target);
-			gtk_drag_finish(drag_context, TRUE, FALSE, time);
-			return;
 		}
-
 		else if(!strcmp(name, NODE2))	// Operating System
 		{
-			on_tilp_send("");
-			gtk_drag_finish(drag_context, TRUE, FALSE, time);
-			return;
+			target=(char *)"";
 		}
-
 		else
 		{
 			if(options.calc_model == CALC_NSPIRE)
@@ -186,14 +184,18 @@ on_treeview1_drag_data_received(GtkWidget * widget,
 			else
 			{
 				// send standard
-				on_tilp_send("");
-				gtk_drag_finish(drag_context, TRUE, FALSE, time);
-				return;
+				target=(char *)"";
 			}
 		}
-	}
 
-	gtk_drag_finish(drag_context, FALSE, FALSE, time);
+		if (target!=NULL)
+			on_tilp_send(target);
+
+		tilp_local_selection_destroy();
+		success = TRUE;
+	}
+end:
+	gtk_drag_finish(drag_context, success, FALSE, _time);
 	return;
 }
 
@@ -228,7 +230,7 @@ GLADE_CB void
 on_treeview1_drag_data_get(GtkWidget * widget,
 			   GdkDragContext * drag_context,
 			   GtkSelectionData * data,
-			   guint info, guint time, gpointer user_data)
+			   guint info, guint _time, gpointer user_data)
 {
 	if (info == TARGET_ROOTWIN) 
 	{
@@ -248,7 +250,7 @@ on_treeview2_drag_data_received(GtkWidget * widget,
 				gint x,
 				gint y,
 				GtkSelectionData * data,
-				guint info, guint time, gpointer user_data)
+				guint info, guint _time, gpointer user_data)
 {
 	if ((data->length >= 0) && (data->format == 8)) 
 	{
@@ -307,11 +309,11 @@ on_treeview2_drag_data_received(GtkWidget * widget,
 			on_tilp_button5_clicked(NULL, NULL);
 		}
 
-		gtk_drag_finish(drag_context, TRUE, FALSE, time);
+		gtk_drag_finish(drag_context, TRUE, FALSE, _time);
 		return;
 	}
 
-	gtk_drag_finish(drag_context, FALSE, FALSE, time);
+	gtk_drag_finish(drag_context, FALSE, FALSE, _time);
 	return;
 }
 
