@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: filesel.c 4026 2007-11-11 20:15:43Z roms $ */
+/* $Id$ */
 
 /*  TiLP - Tilp Is a Linking Program
  *
@@ -59,14 +59,12 @@
 #include "filesel.h"
 #include "tilp_struct.h"
 
-#define GTK_REFRESH() { while( gtk_events_pending() ) { gtk_main_iteration(); }}
-
 /* Single file selectors */
 
 static gchar *fname = NULL;
 
 // GTK >= 2.4
-static const gchar* create_fsel_2(gchar *dirname, gchar *filename, gchar *ext, gboolean save)
+static const gchar* create_fsel_2(const gchar *dirname, const gchar *filename, const gchar *ext, gboolean save)
 {
 	GtkWidget *dialog;
 	GtkFileFilter *filter;
@@ -123,7 +121,7 @@ static const gchar* create_fsel_2(gchar *dirname, gchar *filename, gchar *ext, g
 }
 
 // WIN32
-static const gchar* create_fsel_3(gchar *dirname, gchar *filename, gchar *ext, gboolean save)
+static const gchar* create_fsel_3(const gchar *dirname, const gchar *filename, const gchar *ext, gboolean save)
 {
 #ifdef WIN32
 	OPENFILENAME_MAYALIAS o;
@@ -242,7 +240,7 @@ static const gchar* create_fsel_3(gchar *dirname, gchar *filename, gchar *ext, g
 }
 
 // KDE
-static const gchar* create_fsel_4(gchar *dirname, gchar *filename, gchar *ext, gboolean save)
+static const gchar* create_fsel_4(const gchar *dirname, const gchar *filename, const gchar *ext, gboolean save)
 {
 #if WITH_KDE
 	gchar *p;
@@ -268,7 +266,7 @@ static const gchar* create_fsel_4(gchar *dirname, gchar *filename, gchar *ext, g
 }
 
 // Front-end
-const gchar *create_fsel(gchar *dirname, gchar *filename, gchar *ext, gboolean save)
+const gchar *create_fsel(const gchar *dirname, const gchar *filename, const gchar *ext, gboolean save)
 {
 #ifndef __WIN32__
 	if(options.fs_type == 2)
@@ -305,7 +303,7 @@ const gchar *create_fsel(gchar *dirname, gchar *filename, gchar *ext, gboolean s
 static gchar** filenames = NULL;
 
 // GTK >= 2.4
-static gchar** create_fsels_2(gchar *dirname, gchar *filename, gchar *ext)
+static gchar** create_fsels_2(const gchar *dirname, const gchar *filename, const gchar *ext)
 {
 	GtkWidget *dialog;
 	GtkFileFilter *filter;
@@ -374,7 +372,7 @@ static gchar** create_fsels_2(gchar *dirname, gchar *filename, gchar *ext)
 }
 
 // WIN32
-static gchar** create_fsels_3(gchar *dirname, gchar *filename, gchar *ext)
+static gchar** create_fsels_3(const gchar *dirname, const gchar *filename, const gchar *ext)
 {
 #ifdef WIN32
 	OPENFILENAME_MAYALIAS o;
@@ -515,7 +513,7 @@ static gchar** create_fsels_3(gchar *dirname, gchar *filename, gchar *ext)
 	return NULL;
 }
 
-static gchar** create_fsels_4(gchar *dirname, gchar *filename, gchar *ext)
+static gchar** create_fsels_4(const gchar *dirname, const gchar *filename, const gchar *ext)
 {
 #if WITH_KDE
 	gchar *p;
@@ -531,7 +529,7 @@ static gchar** create_fsels_4(gchar *dirname, gchar *filename, gchar *ext)
 }
 
 // Front-end
-gchar** create_fsels(gchar *dirname, gchar *filename, gchar *ext)
+gchar** create_fsels(const gchar *dirname, const gchar *filename, const gchar *ext)
 {
 #ifndef __WIN32__
 	if(options.fs_type == 2)
