@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: main.c 4148 2008-03-11 22:16:40Z roms $ */
+/* $Id$ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2008  Romain Lievin
@@ -16,8 +16,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,10 +55,21 @@ static void my_log_handler                  (const gchar *log_domain,
                                              const gchar *message,
                                              gpointer user_data) {}
 
+#define LOG_FILE ".tilp.log"
+
 int main(int argc, char *argv[])
 {
 	GdkPixbuf *icon;
 
+	/* Redirect standard output to a file - printing to the Windows terminal slows operation down way too much */
+#ifdef __WIN32__
+	gchar *tmp;
+
+	tmp = g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, LOG_FILE, NULL);
+	freopen(tmp, "w", stdout);
+	g_free(tmp);
+#endif
+
 	/* Init the tilp core */
 	tilp_init(&argc, &argv);
 
@@ -125,7 +136,7 @@ int main(int argc, char *argv[])
 	{
 		gtk_widget_show(main_wnd);
 		toolbar_refresh_buttons();
-		icon = create_pixbuf("icon.xpm");
+		icon = create_pixbuf("tilp.xpm");
 		gtk_window_set_icon(GTK_WINDOW(main_wnd), icon);
 		gdk_window_set_icon_name(main_wnd->window, _("TiLP2"));
 	}
@@ -136,7 +147,7 @@ int main(int argc, char *argv[])
 	 */
 	if((working_mode & MODE_GUI) && (working_mode & MODE_CMD)) 
 	{
-		extern int on_tilp_send(char *);
+		extern int on_tilp_send(const char *);
 
 		splash_screen_set_label(_("Command line..."));
 
