@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: screenshot.c 3976 2007-11-05 13:08:26Z roms $ */
+/* $Id$ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -15,8 +15,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +29,6 @@
 
 #include "support.h"
 #include "screenshot.h"
-#include "support.h"
 #include "dboxes.h"
 #include "scroptions.h"
 #include "filesel.h"
@@ -89,7 +88,7 @@ GLADE_CB void on_sc_save1_activate(GtkMenuItem * menuitem,
 	GdkPixbuf *pixbuf;
 	gboolean result = FALSE;
 	GError *error = NULL;
-	gchar *type;
+	const gchar *type;
 	const gchar *filename = NULL;
 
 	if(screen_success == FALSE)
@@ -188,9 +187,9 @@ GLADE_CB void on_scdbox_button1_clicked(GtkButton * button,
 	guchar *bytemap;
 	gint w, h;
 
-	if (screen_capture()) 
+	if (screen_capture())
 	{
-		screen_success = FALSE;	
+		screen_success = FALSE;
 		return;
 	} 
 	else
@@ -209,7 +208,32 @@ GLADE_CB void on_scdbox_button1_clicked(GtkButton * button,
 			bytemap = screen_bw_convert();
 	}
 	else
-		bytemap = screen_gs_convert();
+	{
+		// For Nspires, we have to determine the calc model...
+		CalcInfos infos;
+		if (ticalcs_calc_get_version(calc_handle, &infos))
+		{
+			screen_success = FALSE;
+			return;
+		}
+
+		if (infos.bits_per_pixel == 4)
+		{
+			// Nspire (CAS) Clickpad or Touchpad.
+			bytemap = screen_gs_convert();
+		}
+		else if (infos.bits_per_pixel == 16)
+		{
+			// Nspire (CAS) CX.
+			bytemap = screen_16bitcolor_convert();
+		}
+		else
+		{
+			tilp_critical(_("Unknown calculator model with %d bpp\n"), infos.bits_per_pixel);
+			screen_success = FALSE;
+			return;
+		}
+	}
 
 	pixbuf = gdk_pixbuf_new_from_data(bytemap, GDK_COLORSPACE_RGB, FALSE,
 				     8, w, h, 3 * w, destroy_pixbuf, NULL);
