@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_calcs.c 4156 2008-03-26 13:18:03Z roms $ */
+/* $Id$ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -15,8 +15,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
@@ -48,16 +48,19 @@ int tilp_pbar_type(CalcFnctsIdx op)
 	const char **array = calc_handle->calc->counters;
 	const char *str = array[op];
 
-	if(!strcmp(str, "1P"))
-		return 1;
-	else if(!strcmp(str, "1L"))
-		return 2;
-	else if(!strcmp(str, "2P"))
-		return 3;
-	else if(!strcmp(str, "1P1L"))
-		return 4;
-	else if(!strcmp(str, "2P1L"))
-		return 5;
+	if (str != NULL)
+	{
+		if(!strcmp(str, "1P"))
+			return 1;
+		else if(!strcmp(str, "1L"))
+			return 2;
+		else if(!strcmp(str, "2P"))
+			return 3;
+		else if(!strcmp(str, "1P1L"))
+			return 4;
+		else if(!strcmp(str, "2P1L"))
+			return 5;
+	}
 
 	return 0;
 }
@@ -242,7 +245,7 @@ int tilp_calc_idlist(int to_file)
 		tilp_err(err);
 		return -1;
 	}
-	
+
 	strcpy(buffer, _("ID-LIST : "));
 	if(options.calc_model != CALC_NSPIRE)
 	{
@@ -269,7 +272,11 @@ int tilp_calc_idlist(int to_file)
 		if(f == NULL)
 			return -1;
 
-		fwrite(buffer, strlen(buffer), 1, f);
+		if (fwrite(buffer, strlen(buffer), 1, f) < 1)
+		{
+			fclose(f);
+			return -1;
+		}
 		fclose(f);
 	}
 	else
@@ -288,9 +295,12 @@ int tilp_calc_rom_dump(void)
 
 	gif->msg_box1(_("Information"), _("ROM contents is copyrighted by Texas Instruments. You are not allowed to copy and/or distribute any ROM image! For more informations, see the License Agreement provided with any FLASH OS upgrade."));
 
-	ret = gif->msg_box4(_("Warning"), _("An assembly program is about to be sent on your calculator.\nIf you have not made a backup yet, you should do one before\nproceeding with ROM dumping...\n\nFor the way of proceeding, take a look at the TiLP manual \n(especially if you have a USB cable)."));
-	if(ret != BUTTON1)
-		return -1;
+	if (options.calc_model != CALC_NSPIRE)
+	{
+		ret = gif->msg_box4(_("Warning"), _("An assembly program is about to be sent on your calculator.\nIf you have not made a backup yet, you should do one before\nproceeding with ROM dumping...\n\nFor the way of proceeding, take a look at the TiLP manual \n(especially if you have a USB cable)."));
+		if(ret != BUTTON1)
+			return -1;
+	}
 
 	/* Transfer ROM dumper */
 	gif->create_pbar_(FNCT_DUMP_ROM, _("Dumping ROM"));
@@ -307,7 +317,6 @@ int tilp_calc_rom_dump(void)
 		case CALC_TI82: gif->msg_box1("Information", "Launch the ROM dumper on your TI-82 by entering the following commands: PRGM, EXEC, ROMDUMP. Next, press Close."); break;
 		case CALC_TI85: gif->msg_box1("Information", "Launch the ROM dumper on your TI-85 by CUSTOM, F1, scroll down to ROMDUMP, ENTER. Next, press Close."); break;
 		case CALC_TI86: gif->msg_box1("Information", "Launch the ROM dumper on your TI-86 by typing ASM(ROMDump), ENTER. Next, press Close."); break;
-		case CALC_TI84P_USB: gif->msg_box1("Information", "Launch the ROM dumper on your TI-8X+ by entering the following commands: PRGM, EXEC, ROMDUMP. Next, press Close."); break;
 	}
 
 	/* Get data from dumper */
@@ -346,7 +355,7 @@ int tilp_calc_send_app(void)
 
 		if(tifiles_file_test(f->name, TIFILE_OS, CALC_NONE))
 		{
-			gif->msg_box1(_("Error"), _("You can not send variables/applications and upgrades simultaneously."));
+			gif->msg_box1(_("Error"), _("You cannot send variables/applications and upgrades simultaneously."));
 			return 0;
 		}
 	}
@@ -455,7 +464,7 @@ int tilp_calc_send_os(const char *filename)
 int tilp_calc_recv_app(void)
 {
 	GList *ptr;
-	char filename[256];
+	char filename[261];
 	char *dst;
 	int i, l;
 
@@ -547,7 +556,7 @@ int tilp_calc_send_var(void)
 		}
 		if(tifiles_file_test(f->name, TIFILE_OS, options.calc_model))
 		{
-			gif->msg_box1(_("Error"), _("You can not send both variables/applications and upgrades simultaneously."));
+			gif->msg_box1(_("Error"), _("You cannot send both variables/applications and upgrades simultaneously."));
 			return 0;
 		}
 		else if(tifiles_file_is_app(f->name))
@@ -556,7 +565,7 @@ int tilp_calc_send_var(void)
 		}
 		else if(tifiles_file_is_backup(f->name) && !tifiles_file_is_group(f->name)) 
 		{
-			gif->msg_box1(_("Error"), _("You can not send backups in this way. Use the 'Restore' button instead."));
+			gif->msg_box1(_("Error"), _("You cannot send backups in this way. Use the 'Restore' button instead."));
 			return 0;
 		}
 		else if(!tifiles_file_is_regular(f->name) && !tifiles_file_is_tigroup(f->name)) 
@@ -762,7 +771,6 @@ tcrv2:
 		if(options.recv_as_group)
 		{
 			FileContent* content;
-			int err;
 
 			tmp_filename = g_strconcat(g_get_tmp_dir(), G_DIR_SEPARATOR_S, TMPFILE_GROUP, 
 				".", tifiles_fext_of_group(options.calc_model), NULL);
@@ -796,6 +804,7 @@ tcrv2:
 
 			for(i = 0; i < l; i++)
 			{
+				tmp_filename = NULL;
 				err = tifiles_file_write_regular(NULL, array[i], &tmp_filename);
 				if(err)
 				{
@@ -803,18 +812,20 @@ tcrv2:
 					break;
 				}
 
-				src_filename = g_strconcat(g_get_tmp_dir(), G_DIR_SEPARATOR_S, 
-					g_basename(tmp_filename), NULL);
-				dst_filename = g_strconcat(local.cwdir, G_DIR_SEPARATOR_S, 
-					g_basename(tmp_filename), NULL);
+				if (tmp_filename != NULL)
+				{
+					src_filename = g_strconcat(g_get_tmp_dir(), G_DIR_SEPARATOR_S,
+						g_basename(tmp_filename), NULL);
+					dst_filename = g_strconcat(local.cwdir, G_DIR_SEPARATOR_S,
+						g_basename(tmp_filename), NULL);
 
-				tilp_file_move_with_check(src_filename, dst_filename);
+					g_free(tmp_filename);
 
-				g_free(src_filename);
-#ifndef __WIN32__
-				free(tmp_filename);
-#endif
-				g_free(dst_filename);
+					tilp_file_move_with_check(src_filename, dst_filename);
+
+					g_free(dst_filename);
+					g_free(src_filename);
+				}
 			}
 
 			tilp_file_chdir(local.cwdir);
@@ -899,7 +910,7 @@ int tilp_calc_recv_var(void)
 	return 0;
 }
 
-int tilp_calc_check_version(const char *ti9x_ver, const char *ti8x_ver)
+int tilp_calc_check_version(const char *ti9x_ver)
 {
 	if(tifiles_is_flash(options.calc_model))
 	{
@@ -912,7 +923,7 @@ int tilp_calc_check_version(const char *ti9x_ver, const char *ti8x_ver)
 
 		if(tifiles_calc_is_ti9x(options.calc_model))
 		{
-			if(strcmp(infos.os_version, ti9x_ver) < 0)
+			if((ti9x_ver != NULL) && (strcmp(infos.os_version, ti9x_ver) < 0))
 			{
 				gchar *str = g_strdup_printf(_("You need AMS >=%s mini for this operation."), ti9x_ver);
 				gif->msg_box1(_("Information"), str);
@@ -921,15 +932,6 @@ int tilp_calc_check_version(const char *ti9x_ver, const char *ti8x_ver)
 				return -1;
 			}
 		} 
-		else if(tifiles_calc_is_ti8x(options.calc_model))
-		{
-			if(strcmp(infos.os_version, ti8x_ver) < 0)
-			{
-				gchar *str = g_strdup_printf(_("You need OS >=%s mini for this operation."), ti8x_ver);
-				gif->msg_box1(_("Information"), str);
-				return -1;
-			}
-		}
 	}
 
 	return 0;
@@ -949,7 +951,7 @@ int tilp_calc_del_var(void)
 	if(!(ticalcs_calc_features(calc_handle) & OPS_DELVAR))
 		return 0;
 
-	if(tilp_calc_check_version("2.09", "2.00") < 0)
+	if(tilp_calc_check_version("2.09") < 0)
 		return -1;
 
 	if(options.overwrite)
@@ -1007,6 +1009,13 @@ int tilp_calc_new_fld(void)
 	if(!(ticalcs_calc_features(calc_handle) & OPS_NEWFLD))
 		return 0;
 
+	// This operation is currently implemented the following way:
+	// * for the legacy I/O port, a temporary file is created and then deleted. The latter requires AMS 2.09.
+	// * for the USB port (AMS >= 3.00), it's always supported.
+	// => require AMS 2.09 or later.
+	if(tilp_calc_check_version("2.09") < 0)
+		return -1;
+
 	fldname = gif->msg_entry(_("New Folder"), _("Name: "), _("folder"));
 	if (fldname == NULL)
 		return 0;
@@ -1097,7 +1106,7 @@ int tilp_calc_get_infos(CalcInfos *infos)
 
 	if(infos->mask & INFOS_LANG_ID)
 	{
-		tmp = g_strdup_printf("%sLanguage Id: %i %i\n", str, infos->language_id, infos->sub_lang_id);
+		tmp = g_strdup_printf(_("%sLanguage Id: %i %i\n"), str, infos->language_id, infos->sub_lang_id);
 		g_free(str);
 		str = tmp;
 	}
@@ -1106,7 +1115,7 @@ int tilp_calc_get_infos(CalcInfos *infos)
 
 	if(infos->mask & INFOS_DEVICE_TYPE)
 	{
-		tmp = g_strdup_printf("%sDevice Type: %02x\n", str, infos->device_type);
+		tmp = g_strdup_printf(_("%sDevice Type: %02x\n"), str, infos->device_type);
 		g_free(str);
 		str = tmp;
 	}
@@ -1124,6 +1133,12 @@ int tilp_calc_get_infos(CalcInfos *infos)
 		g_free(str);
 		str = tmp;
 	}
+	if(infos->mask & INFOS_BOOT2_VERSION)
+	{
+		tmp = g_strdup_printf(_("%sBoot2 Version: %s\n"), str, infos->boot2_version);
+		g_free(str);
+		str = tmp;
+	}
 	if(infos->mask & INFOS_OS_VERSION)
 	{
 		tmp = g_strdup_printf(_("%sOS Version: %s\n"), str, infos->os_version);
@@ -1133,13 +1148,13 @@ int tilp_calc_get_infos(CalcInfos *infos)
 	
 	if(infos->mask & INFOS_RUN_LEVEL)
 	{
-		tmp = g_strdup_printf("%sRun level: %s\n", str, (infos->run_level == 2) ? "OS" : "boot");
+		tmp = g_strdup_printf(_("%sRun level: %s\n"), str, (infos->run_level == 2) ? "OS" : "boot");
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_CLOCK_SPEED)
 	{
-		tmp = g_strdup_printf("%sClock speed: %i MHz\n", str, infos->clock_speed);
+		tmp = g_strdup_printf(_("%sClock speed: %i MHz\n"), str, infos->clock_speed);
 		g_free(str);
 		str = tmp;
 	}
@@ -1148,19 +1163,19 @@ int tilp_calc_get_infos(CalcInfos *infos)
 
 	if(infos->mask & INFOS_LCD_WIDTH)
 	{
-		tmp = g_strdup_printf("%sLCD width: %i pixels\n", str, infos->lcd_width);
+		tmp = g_strdup_printf(_("%sLCD width: %i pixels\n"), str, infos->lcd_width);
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_LCD_HEIGHT)
 	{
-		tmp = g_strdup_printf("%sLCD height: %i pixels\n", str, infos->lcd_height);
+		tmp = g_strdup_printf(_("%sLCD height: %i pixels\n"), str, infos->lcd_height);
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_BPP)
 	{
-		tmp = g_strdup_printf("%sBits per pixel: %i\n", str, infos->bits_per_pixel);
+		tmp = g_strdup_printf(_("%sBits per pixel: %i\n"), str, infos->bits_per_pixel);
 		g_free(str);
 		str = tmp;
 	}
