@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_screen.c 4155 2008-03-26 13:15:55Z roms $ */
+/* $Id$ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -16,8 +16,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
@@ -214,6 +214,36 @@ uint8_t* screen_gs_convert(void)
 	return bytemap;
 }
 
+/*
+  Convert an NSpire CX 16-bit color bitmap into a bytemap.
+  The returned RRGGBB array must be freed when no longer used.
+*/
+uint8_t* screen_16bitcolor_convert(void)
+{
+	guchar *bitmap  = screen.bitmap;
+	gint w = screen.width;
+	gint h = screen.height;
+	guchar *bytemap = g_malloc(3 * w * h);
+	int i, j;
+
+	for (i = 0; i < h; i++)
+	{
+		for (j = 0; j < w; j++)
+		{
+			uint16_t data = ((uint16_t *)bitmap)[w * i + j];
+
+			int pos = w*i + j;
+
+			// Current code: R5 G6 B5. Let's see if it's correct.
+			bytemap[3 * pos + 0] = ((data & 0xF800) >> 11) << 3;
+			bytemap[3 * pos + 1] = ((data & 0x07E0) >>  5) << 2;
+			bytemap[3 * pos + 2] = ((data & 0x001F) >>  0) << 3;
+		}
+	}
+
+	return bytemap;
+}
+
 /*
  * Utility function for the EPS and PDF output
  */
